aboutsummaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorEthan Halsall <ethanhalsall11@augustana.edu>2023-03-12 12:53:03 -0500
committerSteve Markgraf <steve@steve-m.de>2024-03-10 23:01:56 +0100
commite04c42c019bcc24561d146d318e01d4c008bdb48 (patch)
treeae23d0f44d7d61dc44ae46fe8b1fef64a2a14195 /src
parentef23f806ec6c8791ef3b21dcf6bbbe76479b0335 (diff)
fix: set fc0012 gain to low on init
Diffstat (limited to 'src')
-rw-r--r--src/tuner_fc0012.c2
1 files changed, 1 insertions, 1 deletions
diff --git a/src/tuner_fc0012.c b/src/tuner_fc0012.c
index 768cf1c..30969f6 100644
--- a/src/tuner_fc0012.c
+++ b/src/tuner_fc0012.c
@@ -114,7 +114,7 @@ int fc0012_init(void *dev)
0x00, /* reg. 0x10: may also be 0x0d */
0x00, /* reg. 0x11 */
0x1f, /* reg. 0x12: Set to maximum gain */
- 0x08, /* reg. 0x13: Set to Middle Gain: 0x08,
+ 0x00, /* reg. 0x13: Set to Low Gain: 0x00,
Low Gain: 0x00, High Gain: 0x10, enable IX2: 0x80 */
0x00, /* reg. 0x14 */
0x04, /* reg. 0x15: Enable LNA COMPS */